@@ -53,6 +53,7 @@ module Control.Exception.Lens
   , trying, trying_
   -- * Throwing
   , throwing
+  , throwing_
   , throwingM
   , throwingTo
   -- * Mapping
@@ -160,6 +161,21 @@ module Control.Exception.Lens
   , AsErrorCall(..)
 #if __GLASGOW_HASKELL__ >= 710
   , pattern ErrorCall_
+#endif
+#if MIN_VERSION_base(4,8,0)
+  -- ** Allocation Limit Exceeded
+  , AsAllocationLimitExceeded(..)
+  , pattern AllocationLimitExceeded_
+#endif
+#if MIN_VERSION_base(4,9,0)
+  -- ** Type Error
+  , AsTypeError(..)
+  , pattern TypeError_
+#endif
+#if MIN_VERSION_base(4,10,0)
+  -- ** Compaction Failed
+  , AsCompactionFailed(..)
+  , pattern CompactionFailed_
 #endif
   -- * Handling Exceptions
   , AsHandlingException(..)
@@ -348,6 +364,18 @@ throwing :: AReview SomeException b -> b -> r
 throwing l = reviews l Exception.throw
 {-# INLINE throwing #-}
 
+-- | Similar to 'throwing' but specialised for the common case of
+--   error constructors with no arguments.
+--
+-- @
+-- data MyError = Foo | Bar
+-- makePrisms ''MyError
+-- 'throwing_' _Foo :: 'MonadError' MyError m => m a
+-- @
+throwing_ :: AReview SomeException () -> m x
+throwing_ l = throwing l ()
+{-# INLINE throwing_ #-}
+
 -- | A variant of 'throwing' that can only be used within the 'IO' 'Monad'
 -- (or any other 'MonadCatch' instance) to throw an 'Exception' described
 -- by a 'Prism'.
@@ -1124,6 +1152,90 @@ pattern ErrorCall_ e <- (preview _ErrorCall -> Just e) where
   ErrorCall_ e = review _ErrorCall e
 #endif
 
+#if MIN_VERSION_base(4,8,0)
+----------------------------------------------------------------------------
+-- AllocationLimitExceeded
+----------------------------------------------------------------------------
+
+-- | This thread has exceeded its allocation limit.
+class AsAllocationLimitExceeded t where
+  -- | There is no additional information carried in an
+  -- 'AllocationLimitExceeded' 'Exception'.
+  --
+  -- @
+  -- '_AllocationLimitExceeded' :: 'Prism'' 'AllocationLimitExceeded' ()
+  -- '_AllocationLimitExceeded' :: 'Prism'' 'SomeException'           ()
+  -- @
+  _AllocationLimitExceeded :: Prism' t ()
+
+instance AsAllocationLimitExceeded AllocationLimitExceeded where
+  _AllocationLimitExceeded = trivial AllocationLimitExceeded
+  {-# INLINE _AllocationLimitExceeded #-}
+
+instance AsAllocationLimitExceeded SomeException where
+  _AllocationLimitExceeded = exception.trivial AllocationLimitExceeded
+  {-# INLINE _AllocationLimitExceeded #-}
+
+pattern AllocationLimitExceeded_ <- (has _AllocationLimitExceeded -> True) where
+  AllocationLimitExceeded_ = review _AllocationLimitExceeded ()
+#endif
+
+#if MIN_VERSION_base(4,9,0)
+----------------------------------------------------------------------------
+-- TypeError
+----------------------------------------------------------------------------
+
+-- | An expression that didn't typecheck during compile time was called.
+-- This is only possible with @-fdefer-type-errors@.
+class AsTypeError t where
+  -- | Details about the failed type check.
+  --
+  -- @
+  -- '_TypeError' :: 'Prism'' 'TypeError'     ()
+  -- '_TypeError' :: 'Prism'' 'SomeException' ()
+  -- @
+  _TypeError :: Prism' t String
+
+instance AsTypeError TypeError where
+  _TypeError = _Wrapping TypeError
+  {-# INLINE _TypeError #-}
+
+instance AsTypeError SomeException where
+  _TypeError = exception._Wrapping TypeError
+  {-# INLINE _TypeError #-}
+
+pattern TypeError_ e <- (preview _TypeError -> Just e) where
+  TypeError_ e = review _TypeError e
+#endif
+
+#if MIN_VERSION_base(4,10,0)
+----------------------------------------------------------------------------
+-- CompactionFailed
+----------------------------------------------------------------------------
+
+-- | Compaction found an object that cannot be compacted.
+-- Functions cannot be compacted, nor can mutable objects or pinned objects.
+class AsCompactionFailed t where
+  -- | Information about why a compaction failed.
+  --
+  -- @
+  -- '_CompactionFailed' :: 'Prism'' 'CompactionFailed' ()
+  -- '_CompactionFailed' :: 'Prism'' 'SomeException'    ()
+  -- @
+  _CompactionFailed :: Prism' t String
+
+instance AsCompactionFailed CompactionFailed where
+  _CompactionFailed = _Wrapping CompactionFailed
+  {-# INLINE _CompactionFailed #-}
+
+instance AsCompactionFailed SomeException where
+  _CompactionFailed = exception._Wrapping CompactionFailed
+  {-# INLINE _CompactionFailed #-}
+
+pattern CompactionFailed_ e <- (preview _CompactionFailed -> Just e) where
+  CompactionFailed_ e = review _CompactionFailed e
+#endif
+
 ------------------------------------------------------------------------------
 -- HandlingException
 ------------------------------------------------------------------------------
