@@ -166,7 +166,6 @@ import Data.Profunctor.Unsafe
 import Data.Reflection
 import Data.Semigroup.Traversable
 import Data.Semigroup.Bitraversable
-import Data.Tagged
 import Data.Traversable
 import Data.Tuple (swap)
 import GHC.Magic (inline)
@@ -230,11 +229,11 @@ type AnIndexedTraversal1' i s a = AnIndexedTraversal1 i s s a a
 --
 --  * a 'Traversal' if @f@ is 'Applicative',
 --
---  * a 'Getter' if @f@ is only a 'Functor' and 'Contravariant',
+--  * a 'Getter' if @f@ is only a 'Functor' and 'Data.Functor.Contravariant.Contravariant',
 --
---  * a 'Lens' if @p@ is only a 'Functor',
+--  * a 'Lens' if @f@ is only a 'Functor',
 --
---  * a 'Fold' if @f@ is 'Functor', 'Contravariant' and 'Applicative'.
+--  * a 'Fold' if @f@ is 'Applicative' and 'Data.Functor.Contravariant.Contravariant'.
 type Traversing p f s t a b = Over p (BazaarT p f a b) s t a b
 
 type Traversing1 p f s t a b = Over p (BazaarT1 p f a b) s t a b
@@ -505,7 +504,7 @@ iloci f w = getCompose (runBazaar w (Compose #. Indexed (\i -> fmap (indexed sel
 {-# INLINE iloci #-}
 
 -------------------------------------------------------------------------------
--- Parts and Holes
+-- Parts
 -------------------------------------------------------------------------------
 
 -- | 'partsOf' turns a 'Traversal' into a 'Lens' that resembles an early version of the 'Data.Data.Lens.uniplate' (or 'Data.Data.Lens.biplate') type.
@@ -601,36 +600,6 @@ iunsafePartsOf' l = conjoined
   (\f s -> let b = inline l sell s; (is, as) = unzip (pins b) in unsafeOuts b <$> indexed f (is :: [i]) as)
 {-# INLINE iunsafePartsOf' #-}
 
--- | The one-level version of 'Control.Lens.Plated.contextsOf'. This extracts a list of the immediate children according to a given 'Traversal' as editable contexts.
---
--- Given a context you can use 'Control.Comonad.Store.Class.pos' to see the values, 'Control.Comonad.Store.Class.peek' at what the structure would be like with an edited result, or simply 'extract' the original structure.
---
--- @
--- propChildren l x = childrenOf l x '==' 'map' 'Control.Comonad.Store.Class.pos' ('holesOf' l x)
--- propId l x = 'all' ('==' x) ['extract' w | w <- 'holesOf' l x]
--- @
---
--- @
--- 'holesOf' :: 'Iso'' s a                -> s -> ['Pretext'' (->) a s]
--- 'holesOf' :: 'Lens'' s a               -> s -> ['Pretext'' (->) a s]
--- 'holesOf' :: 'Traversal'' s a          -> s -> ['Pretext'' (->) a s]
--- 'holesOf' :: 'IndexedLens'' i s a      -> s -> ['Pretext'' ('Indexed' i) a s]
--- 'holesOf' :: 'IndexedTraversal'' i s a -> s -> ['Pretext'' ('Indexed' i) a s]
--- @
-holesOf :: forall p s t a. Conjoined p => Over p (Bazaar p a a) s t a a -> s -> [Pretext p a a t]
-holesOf l s = unTagged
-  ( conjoined
-     (Tagged $ let
-        f [] _ = []
-        f (x:xs) g = Pretext (\xfy -> g . (:xs) <$> xfy x) : f xs (g . (x:))
-      in f (ins b) (unsafeOuts b))
-     (Tagged $ let
-        f [] _ = []
-        f (wx:xs) g = Pretext (\wxfy -> g . (:Prelude.map extract xs) <$> cosieve wxfy wx) : f xs (g . (extract wx:))
-      in f (pins b) (unsafeOuts b))
-    :: Tagged (p a b) [Pretext p a a t]
-  ) where b = l sell s
-{-# INLINE holesOf #-}
 
 -- | This converts a 'Traversal' that you \"know\" will target one or more elements to a 'Lens'. It can
 -- also be used to transform a non-empty 'Fold' into a 'Getter'.
@@ -699,7 +668,7 @@ unsafeSingular l = conjoined
 {-# INLINE unsafeSingular #-}
 
 ------------------------------------------------------------------------------
--- Internal functions used by 'partsOf', 'holesOf', etc.
+-- Internal functions used by 'partsOf', etc.
 ------------------------------------------------------------------------------
 
 ins :: Bizarre (->) w => w a b t -> [a]
@@ -732,6 +701,78 @@ unconsWithDefault d []     = (d,[])
 unconsWithDefault _ (x:xs) = (x,xs)
 {-# INLINE unconsWithDefault #-}
 
+
+-------------------------------------------------------------------------------
+-- Holes
+-------------------------------------------------------------------------------
+
+-- | The one-level version of 'Control.Lens.Plated.contextsOf'. This extracts a
+-- list of the immediate children according to a given 'Traversal' as editable
+-- contexts.
+--
+-- Given a context you can use 'Control.Comonad.Store.Class.pos' to see the
+-- values, 'Control.Comonad.Store.Class.peek' at what the structure would be
+-- like with an edited result, or simply 'extract' the original structure.
+--
+-- @
+-- propChildren l x = 'toListOf' l x '==' 'map' 'Control.Comonad.Store.Class.pos' ('holesOf' l x)
+-- propId l x = 'all' ('==' x) ['extract' w | w <- 'holesOf' l x]
+-- @
+--
+-- @
+-- 'holesOf' :: 'Iso'' s a                -> s -> ['Pretext'' (->) a s]
+-- 'holesOf' :: 'Lens'' s a               -> s -> ['Pretext'' (->) a s]
+-- 'holesOf' :: 'Traversal'' s a          -> s -> ['Pretext'' (->) a s]
+-- 'holesOf' :: 'IndexedLens'' i s a      -> s -> ['Pretext'' ('Indexed' i) a s]
+-- 'holesOf' :: 'IndexedTraversal'' i s a -> s -> ['Pretext'' ('Indexed' i) a s]
+-- @
+holesOf :: Conjoined p
+        => Over p (Bazaar p a a) s t a a -> s -> [Pretext p a a t]
+holesOf f xs = flip appEndo [] . fst $
+  runHoles (runBazaar (f sell xs) (cotabulate holeInOne)) id
+{-# INLINE holesOf #-}
+
+holeInOne :: forall p a t. (Corepresentable p, Category p)
+          => Corep p a -> Holes t (Endo [Pretext p a a t]) a
+holeInOne x = Holes $ \xt ->
+    ( Endo (fmap xt (cosieve sell x) :)
+    , cosieve (id :: p a a) x)
+{-# INLINABLE holeInOne #-}
+
+-- We are very careful to share as much structure as possible among
+-- the results (in the common case where the traversal allows for such).
+-- Note in particular the recursive knot in the implementation of <*>
+-- for Holes. This sharing magic was inspired by Noah "Rampion" Easterly's
+-- implementation of a related holes function: see
+-- https://stackoverflow.com/a/49001904/1477667. The Holes type is
+-- inspired by Roman Cheplyaka's answer to that same question.
+
+newtype Holes t m x = Holes { runHoles :: (x -> t) -> (m, x) }
+
+instance Functor (Holes t m) where
+  fmap f xs = Holes $ \xt ->
+    let
+      (qf, qv) = runHoles xs (xt . f)
+    in (qf, f qv)
+
+instance Monoid m => Applicative (Holes t m) where
+  pure x = Holes $ \_ -> (mempty, x)
+
+  fs <*> xs = Holes $ \xt ->
+    let
+     (pf, pv) = runHoles fs (xt . ($ qv))
+     (qf, qv) = runHoles xs (xt . pv)
+    in (pf `mappend` qf, pv qv)
+
+#if MIN_VERSION_base(4,10,0)
+  liftA2 f xs ys = Holes $ \xt ->
+    let
+      (pf, pv) = runHoles xs (xt . flip f qv)
+      (qf, qv) = runHoles ys (xt . f pv)
+    in (pf `mappend` qf, f pv qv)
+#endif
+
+
 ------------------------------------------------------------------------------
 -- Traversals
 ------------------------------------------------------------------------------
@@ -1274,9 +1315,9 @@ infixl 5 `failing`
 deepOf :: (Conjoined p, Applicative f) => LensLike f s t s t -> Traversing p f s t a b -> Over p f s t a b
 deepOf r l = failing l (r . deepOf r l)
 
--- | "Fuse" a 'Traversal' by reassociating all of the '\<*\>' operations to the
+-- | "Fuse" a 'Traversal' by reassociating all of the '<*>' operations to the
 -- left and fusing all of the 'fmap' calls into one. This is particularly
--- useful when constructing a 'Traversal' using operations from GHC.Generics.
+-- useful when constructing a 'Traversal' using operations from "GHC.Generics".
 --
 -- Given a pair of 'Traversal's 'foo' and 'bar',
 --
